@@ -6,7 +6,7 @@ from typing import Optional, Union
 from .gui import show_auth_gui
 
 __all__ = ('cfg', 'Config', 'database_cfg', 'CONFIG_FOLDER', 'generate_config', 'get_oauth', 'get_nick', 'get_client_id',
-           'DEFAULT_NICK', 'DEFAULT_OAUTH', 'DEFAULT_CLIENT_ID', 'is_config_valid', 'get_command_prefix')
+           'DEFAULT_NICK', 'DEFAULT_OAUTH', 'DEFAULT_CLIENT_ID', 'is_config_valid', 'get_command_prefix', 'message_timer_cfg')
 
 CONFIG_FOLDER = Path('configs')
 
@@ -126,6 +126,11 @@ cfg = Config(
     ],
 )
 
+message_timer_cfg = Config(
+    file_path=CONFIG_FOLDER / 'message_timer_options.json',
+    no_chat_message_auto_disable_seconds=300,
+)
+
 database_cfg = Config(
     CONFIG_FOLDER / 'database_config.json',
     connection='{database_format}+{driver}://{username}:{password}@{address}:{port}/{database}',
